@@ -7,11 +7,9 @@ my $NAME = [
 	qr/Aleksandar/,
 	qr/Aleksandr Guidrevitch/,
 	qr/Alex$/,
-	qr/Alexander Lourier/,
 	qr/Alex Noso/,
 	qr/Alex Prota/,
 	qr/Alexe[iy]/,
-	qr/Aleksey/,
 	qr/Anatoly/,
 	qr/Andre[iy]/,
 	qr/Andrew (?:Maltsev|Shitov|V\. Ma)/,
@@ -20,7 +18,6 @@ my $NAME = [
 	qr/Boris Sukholitko/,
 	qr/Denis \w+[oe]v\b/,
 	qr/Denis S/,
-	qr/(?:Evdokimov|Arapov) Denis/,
 	qr/Dmitr[iy]/,
 	qr/Egor/,
 	qr/Eugen Konkov/,
@@ -56,45 +53,27 @@ print
 	grep { warn scalar @$_ }
 	[
 		# for module
-		map  { sprintf "%-9s => '%s',\n", grep { defined } @$_{'pause', 'name', 'email'} }
+		map  { sprintf "%-9s => '%s',\n", grep { defined } @$_{'pause', 'name'} }
 		sort { $a->{'pause'} cmp $b->{'pause'} }
 		
-		# for list
+		#~ # cpan author
+		#~ grep { $_->{'author'} }
+		
+		# not cpan author, have pause id
+		grep {!$_->{'author'} }
+		
+		#~ # for list
 		#~ map  { join("\t", grep { defined } @$_{'id', 'name', 'pause', 'author', 'email', 'url'}), "\n" }
 		
-		# check email
-		#~ map  { qq{"$_->{'pause'}" $_->{'email'}\n} }
-		#~ grep { $_->{'email'} && $_->{'email'} !~ /CENSORED/ && $_->{'email'} !~ /\.ru$/ }
-		
-		# cpan author
-		grep { $_->{'author'} }
-		
-		#~ # not cpan author, have pause id
-		# grep {!$_->{'author'} }
-		
-		# ru
-		grep { $_->{'pause'} eq 'STEALTHY' and $_->{'author'}=0; 1}
-		grep { $_->{'pause'} !~ /^DZHARIY|IHEFFNER|QUEVLAR|VTI|GUGU|EJS|GRUBER|EGORSH|MVUETS|BEROV|CYBER|NIKIP|TTOD|OMEGA|DRINCHEV|YAKWOO|PLCGI|MADZ|VMS|SHTATLAND|IVAN|ILYA|GREGORY|ERIC|DIMRUB|ANDREI|AXS|MOO|ICHLADIL|IZUT|IKETRIS|IVANS|ITUB|IVANWILLS|IVANWONG|PAVELH|INITDOTD|RUSSOZ$/ }
-		
-		grep { $_->{'email'} !~ /ua$/ }
-		grep { $_->{'email'} !~ /bg$/ }
-		grep { $_->{'email'} !~ /by$/ }
-		grep { $_->{'email'} !~ /ws$/ }
-		grep { $_->{'email'} !~ /cz$/ }
-		
-		# ua
-		# grep { $_->{'pause'} =~ /^VTI|GUGU|EJS|GRUBER|MVUETS|DARKNOS|DZHARIY$/ || $_->{'email'} =~ /ua$/ }
+		# exclude
+		grep { $_->{'pause'} !~ /^YAKWOO|PLCGI|ZAG|MADZ|VMS|SHTATLAND|IVAN|ILYA|GREGORY|ERIC|DIMRUB|ANDREI|AXS|MOO|ICHLADIL|IZUT|IKETRIS|IVANS|ITUB|IVANWILLS|IVANWONG|PAVELH|INITDOTD|RUSSOZ$/ }
 		
 		grep {
-				my $name = $_->{'name'};
-				scalar grep { $name =~ /$_/ } @$NAME;
-			}
-		
-		# no
-		# grep { $_->{pause} =~ /^SJN|MRAMBERG|KRN|ANDREMAR|TRONDMM|ARNE|EIDOLON|NICOMEN|COSIMO|AFF|ESPIZO$/ }
-		
+			my $name = $_->{'name'};
+			scalar grep { $name =~ /$_/ } @$NAME;
+		}
 		map  {
-			my($url,  $name ) = $_->[ 1] =~ /<a href="([^"]+)">([^<]+)/; $name  ||= $_->[ 1]; $name =~ s/\s+$//; $name =~ s/&[^;]+;//sg;
+			my($url,  $name ) = $_->[ 1] =~ /<a href="([^"]+)">([^<]+)/; $name  ||= $_->[ 1]; $name =~ s/\s+$//;
 			my($url2, $pause) = $_->[-1] =~ /<a href="([^"]+)">([^<]+)/; $pause ||= $_->[-1];
 			
 			+{
